@@ -604,9 +604,13 @@ class CommandV(Extensible):
             full_path = os.path.join(dest_dir, element)
             files2backup.append(full_path)
         logger.info('Generating backup with the files %s', ', '.join(files2backup))
-        backup = utils.compress_files(
-            backup_name, files2backup, dest_folder=self.__config.store_path,
-            cformat=self.__config.cformat)
+        if self.__config.cformat == "folder":
+            backup = self.instance_manager._generate_decompressed_backup(
+                files2backup, backup_name, self.__config.store_path)
+        else:
+            backup = utils.compress_files(
+                backup_name, files2backup, dest_folder=self.__config.store_path,
+                cformat=self.__config.cformat)
         postgres.drop(db_name, True)
         if self.__config.upload:
             utils.upload_file(backup, self.__config.upload)
