@@ -2,7 +2,7 @@
 
 import logging
 import os
-from jinja2 import Environment, FileSystemLoader
+from deployv.helpers import utils
 try:
     from xmlrpc import client as xmlrpcclient
 except ImportError:
@@ -12,7 +12,7 @@ except ImportError:
 logger = logging.getLogger(__name__)  # pylint: disable=C0103
 
 
-class NginxV(object):
+class NginxV:
     """Wrapper class around supervisor to manage nginx service and site config files.
 
     :param nginx_working_dir: The path where nginx will store config, logs and pid file.
@@ -75,15 +75,11 @@ class NginxV(object):
 
         :type sites: list
         """
-        path = os.path.join(os.path.dirname(os.path.abspath(__file__)), '../templates/')
-        logger.debug('Searching for the nginx template in: %s', path)
-        env = Environment(loader=FileSystemLoader(path))
-        template = env.get_template('nginx_sites.jinja')
         values = {
             'sites': sites,
             'working_dir': self._working_dir
         }
-        nginx_config = template.render(values)
+        nginx_config = utils.render_template('nginx_sites.jinja', values)
         logger.debug('Saving generated config to %s', self._working_dir)
         with open(os.path.join(self._working_dir, 'nginx.conf'), 'w') as config:
             config.write(nginx_config)
