@@ -7,6 +7,8 @@ import deployv
 from deployv.base import commandv
 from deployv.helpers import utils, configuration_helper, json_helper
 from deployv.instance import instancev
+from deployv.base import postgresv
+import subprocess
 import os
 import re
 import logging
@@ -362,7 +364,22 @@ def deactivate_backup(ctx, prefix, store_path, backup_src, admin_password,
     default_config['instance']['config'].update(db_config)
     config_obj.generate_configuration(default_config)
     command = commandv.CommandV(config_obj)
-    command.deactivate_backup_trigger()
+    try:
+        command.deactivate_backup_trigger()
+    except Exception as error:
+        msg = utils.get_error_message(error)
+        logger.error("Error executing the `deactivate_backup` command: %s", msg)
+        db_name = command._CommandV__config.postgres.get("deactivated_db_name")
+        cmd = 'ls -a %s | grep -P "%s_*"' % (config_obj.store_path, db_name)
+        command.clean_working_folders()
+        postgres = postgresv.PostgresShell(utils.odoo2postgres(db_config))
+        if db_name:
+            postgres.drop(db_name, True)
+            process = subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True)
+            res = process.communicate()[0].strip().decode()
+            for backup in res.split("\n"):
+                backup_path = os.path.join(config_obj.store_path, backup)
+                utils.clean_files(backup_path)
 
 
 @cli.command()
