@@ -935,7 +935,8 @@ class InstanceV(DockerV):
         for file_path in files:
             is_iterable = utils.is_iterable(file_path)
             src = file_path if not is_iterable else file_path[0]
-            dest = tmp_name if not is_iterable else path.join(tmp_name, file_path[1])
+            dest = (path.join(tmp_name, path.basename(file_path)) if not is_iterable else
+                    path.join(tmp_name, file_path[1]))
             logger.info('Adding file %s to %s', src, dest)
             if path.isdir(src):
                 shutil.copytree(src, dest)
@@ -1561,8 +1562,12 @@ class InstanceV(DockerV):
             render the deactivation.jinja file
         """
         logger.info('Deactivating database %s', db_name)
-        db_config = self.db_config
-        db_config.update({'db_name': db_name})
+        db_config = self.db_config.copy()
+        db_config.update({
+            'db_name': db_name,
+            'db_user': db_config.get("db_owner") or db_config.get('db_user'),
+            'db_password': db_config.get('db_owner_passwd') or db_config.get('db_password'),
+        })
         db_config = utils.odoo2postgres(db_config)
         extra_config = extra_config or {}
         extra_sqls = self.extras_deactivate()
