@@ -18,7 +18,7 @@ class HttpWorker(BaseWorker):
         """ Worker method, runs the method that performs a request to the odoo controller
         and retrieves the messages
         """
-        _logger.info("W%s - waiting for something to do", self._wid)
+        _logger.info("Worker %s - waiting for something to do", self._wid)
         try:
             self._receiver.run(self.callback)
         except errors.GracefulExit:
